<?php
/**
 * Dhimay functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Dhimay
 */
/**
 * Add an HTML class to MediaElement.js container elements to aid styling.
 *
 * Extends the core _wpmejsSettings object to add a new feature via the
 * MediaElement.js plugin API.
 */
function dhimay_mejs_add_container_class() {
	if ( ! wp_script_is( 'mediaelement', 'done' ) ) {
		return;
	}
	?>
	<script>
		if(wpContainer) {
			let wpNext = document.querySelector('.wp-playlist-next');
			let wpPrev = document.querySelector('.wp-playlist-prev');
			wpNext.classList.add('dashicons','dashicons-controls-skipforward');
			wpPrev.classList.add('dashicons','dashicons-controls-skipback');
		}
	</script>
	<?php
}
add_action( 'wp_print_footer_scripts', 'dhimay_mejs_add_container_class' );


if ( ! function_exists( 'dhimay_after_theme_support' ) ) :

	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */

	function dhimay_after_theme_support() {

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		// Custom background color.
		add_theme_support(
			'custom-background',
			array(
				'default-color' => '#FFFFFF',
			)
		);

		// This variable is intended to be overruled from themes.
		// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
		// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
		$GLOBALS['content_width'] = apply_filters( 'dhimay_content_width', 970 );
		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		add_theme_support(
			'custom-logo',
			array(
				'height'      => 120,
				'width'       => 90,
				'flex-height' => true,
				'flex-width'  => true,
			)
		);

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'script',
				'style',
			)
		);

		/*
		 * Posts Formate.
		 *
		 * https://wordpress.org/support/article/post-formats/
		 */
		add_theme_support( 'post-formats', array(
		    'video',
		    'audio',
		    'gallery',
		    'quote',
		    'image'
		) );

		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Dhimay, use a find and replace
		 * to change 'dhimay' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'dhimay', get_template_directory() . '/languages' );

        /*
         * Enable support Gutenberg and Block styles.
         *
         */
        add_theme_support( 'align-wide' );
        add_theme_support( 'responsive-embeds' );
        add_theme_support( 'wp-block-styles' );

	}

endif;

add_action( 'after_setup_theme', 'dhimay_after_theme_support' );

function dhimay_next_posts_link( $max_page = 0 ) {
    global $paged, $wp_query;

    if ( ! $max_page ) {
        $max_page = $wp_query->max_num_pages;
    }

    if ( ! $paged ) {
        $paged = 1;
    }

    $next_page = (int) $paged + 1;
    if ( ( $next_page <= $max_page ) ) {
        /**
         * Filters the anchor tag attributes for the next posts page link.
         *
         * @since 2.7.0
         *
         * @param string $attributes Attributes for the anchor tag.
         */
        $attr = apply_filters( 'next_posts_link_attributes', '' );

        return sprintf(next_posts( $max_page, false ));
    }
}

/**
 * Register and Enqueue Styles.
 */
function dhimay_register_styles() {

	$dhimay_default = dhimay_get_default_theme_options();
	
	$theme_version = wp_get_theme()->get( 'Version' );
	$fonts_url = dhimay_fonts_url();
    if( $fonts_url ){
    	
    	require_once get_theme_file_path( 'assets/lib/custom/css/wptt-webfont-loader.php' );
        wp_enqueue_style(
			'dhimay-google-fonts',
			wptt_get_webfont_url( $fonts_url ),
			array(),
			$theme_version
		);
    }


    wp_enqueue_style( 'slick', get_template_directory_uri() . '/assets/lib/slick/css/slick.min.css');
    wp_enqueue_style( 'accessible-slick', get_template_directory_uri() . '/assets/lib/slick/css/accessible-slick-theme.min.css');

    if( class_exists('WooCommerce') ){

	    wp_enqueue_style( 'dhimay-woocommerce', get_template_directory_uri() . '/assets/lib/custom/css/woocommerce.css' );

	}
	wp_enqueue_style( 'dhimay-style', get_stylesheet_uri(), array(), $theme_version );
    wp_style_add_data('dhimay-style', 'rtl', 'replace');

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}	

	wp_enqueue_script( 'imagesloaded' );
    wp_enqueue_script( 'masonry' );
    wp_enqueue_script( 'wp-mediaelement' );
	wp_enqueue_style( 'dashicons' );

    wp_enqueue_style( 'magnific-popup', get_template_directory_uri() . '/assets/lib/magnific-popup/magnific-popup.css' );
	wp_enqueue_script( 'slick', get_template_directory_uri() . '/assets/lib/slick/js/slick.min.js', array('jquery'), '', 1);

	wp_enqueue_script( 'magnific-popup', get_template_directory_uri() . '/assets/lib/magnific-popup/jquery.magnific-popup.min.js', array('jquery'), '', true );
	wp_enqueue_script( 'dhimay-pagination', get_template_directory_uri() . '/assets/lib/custom/js/pagination.js', array('jquery'), '', 1 );
	wp_enqueue_script( 'dhimay-custom', get_template_directory_uri() . '/assets/lib/custom/js/custom.js', array('jquery'), '', 1);
    $ajax_nonce = wp_create_nonce('dhimay_ajax_nonce');
    

    // Global Query
    if( is_front_page() ){

    	$posts_per_page = absint( get_option('posts_per_page') );
        $paged = ( get_query_var( 'page' ) ) ? absint( get_query_var( 'page' ) ) : 1;

        $posts_args = array(
            'posts_per_page'        => $posts_per_page,
            'paged'                 => $paged,
        );

        $posts_qry = new WP_Query( $posts_args );
        $max = $posts_qry->max_num_pages;

    }else{

        global $wp_query;
        $max = $wp_query->max_num_pages;
        $paged = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;

    }

    $dhimay_default = dhimay_get_default_theme_options();
    $dhimay_pagination_layout = get_theme_mod( 'dhimay_pagination_layout',$dhimay_default['dhimay_pagination_layout'] );

    $permalink_structure = get_option('permalink_structure');
    // Pagination Data
    wp_localize_script( 
	    'dhimay-pagination', 
	    'dhimay_pagination',
	    array(
	        'paged'  => absint( $paged ),
	        'maxpage'   => absint( $max ),
            'nextLink'   => dhimay_next_posts_link($max ),
	        'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
	        'loadmore'   => esc_html__( 'Load More Posts', 'dhimay' ),
	        'nomore'     => esc_html__( 'No More Posts', 'dhimay' ),
	        'loading'    => esc_html__( 'Loading...', 'dhimay' ),
	        'pagination_layout'   => esc_html( $dhimay_pagination_layout ),
            'permalink_structure'   => esc_html( $permalink_structure ),
	        'ajax_nonce' => $ajax_nonce,
	     )
	);

    global $post;
    $single_post = 0;
    $dhimay_ed_post_reaction = '';

    if( isset( $post->ID ) && isset( $post->post_type ) && $post->post_type == 'post' ){

    	$dhimay_ed_post_reaction = esc_html( get_post_meta( $post->ID, 'dhimay_ed_post_reaction', true ) );
    	$single_post = 1;

    }
    
	wp_localize_script(
	    'dhimay-custom', 
	    'dhimay_custom',
	    array(
	    	'single_post'	=> absint( $single_post ),
	        'dhimay_ed_post_reaction'  		=> esc_html( $dhimay_ed_post_reaction ),
	        'play' => dhimay_the_theme_svg( 'play', $return = true ),
            'pause' => dhimay_the_theme_svg( 'pause', $return = true ),
            'mute' => dhimay_the_theme_svg( 'mute', $return = true ),
            'unmute' => dhimay_the_theme_svg( 'unmute', $return = true ),
            'play_text' => esc_html__('Play','dhimay'),
            'pause_text' => esc_html__('Pause','dhimay'),
            'mute_text' => esc_html__('Mute','dhimay'),
            'unmute_text' => esc_html__('Unmute','dhimay'),
	     )
	);

}

add_action( 'wp_enqueue_scripts', 'dhimay_register_styles' );

/**
 * Admin enqueue script
 */
function dhimay_admin_scripts($hook){

	wp_enqueue_media();
    wp_enqueue_style('dhimay-admin', get_template_directory_uri() . '/assets/lib/custom/css/admin.css');
    wp_enqueue_script('dhimay-admin', get_template_directory_uri() . '/assets/lib/custom/js/admin.js', array('jquery'), '', 1);
    
    $ajax_nonce = wp_create_nonce('dhimay_ajax_nonce');

    wp_localize_script( 
        'dhimay-admin', 
        'dhimay_admin',
        array(
            'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
            'ajax_nonce' => $ajax_nonce,
            'active' => esc_html__('Active','dhimay'),
	        'deactivate' => esc_html__('Deactivate','dhimay'),
	        'upload_image'   =>  esc_html__('Choose Image','dhimay'),
            'use_image'   =>  esc_html__('Select','dhimay'),
         )
    );
}

add_action('admin_enqueue_scripts', 'dhimay_admin_scripts');

if( !function_exists( 'dhimay_js_no_js_class' ) ) :

	// js no-js class toggle
	function dhimay_js_no_js_class() { ?>

		<script>document.documentElement.className = document.documentElement.className.replace( 'no-js', 'js' );</script>
	
	<?php
	}
	
endif;

add_action( 'wp_head', 'dhimay_js_no_js_class' );

/**
 * Register navigation menus uses wp_nav_menu in five places.
 */
function dhimay_menus() {

	$locations = array(
		'dhimay-primary-menu'  => esc_html__( 'Primary Menu', 'dhimay' ),
		'dhimay-social-menu'  => esc_html__( 'Social Menu', 'dhimay' ),
	);

	register_nav_menus( $locations );
}

add_action( 'init', 'dhimay_menus' );

add_filter('themeinwp_enable_demo_import_compatiblity','dhimay_demo_import_filter_apply');

if( !function_exists('dhimay_demo_import_filter_apply') ):

	function dhimay_demo_import_filter_apply(){

		return true;

	}

endif;
/**
 * Implement Custom feature.
 */
require get_template_directory() . '/inc/custom-header.php';
require get_template_directory() . '/assets/lib/tgmpa/recommended-plugins.php';
require get_template_directory() . '/classes/class-svg-icons.php';
require get_template_directory() . '/classes/class-walker-menu.php';
require get_template_directory() . '/classes/plugin-classes.php';
require get_template_directory() . '/classes/about.php';
require get_template_directory() . '/classes/admin-notice.php';
require get_template_directory() . '/inc/customizer/customizer.php';
require get_template_directory() . '/inc/single-related-posts.php';
require get_template_directory() . '/inc/custom-functions.php';
require get_template_directory() . '/inc/homepage-section.php';
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/classes/body-classes.php';
require get_template_directory() . '/inc/widgets/widgets.php';
require get_template_directory() . '/inc/metabox.php';
require get_template_directory() . '/inc/term-meta.php';
require get_template_directory() . '/inc/pagination.php';
require get_template_directory() . '/assets/lib/breadcrumbs/breadcrumbs.php';
require get_template_directory() . '/assets/lib/custom/css/style.php';
require get_template_directory() . '/woocommerce/woocommerce-functions.php';